@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 
 __title__ = 'purl'
-__version__ = '0.5'
+__version__ = '0.6'
 __author__ = 'David Winterbottom'
 __license__ = 'MIT'
 
@@ -13,6 +13,18 @@ except ImportError:
 from collections import namedtuple
 
 
+# Python 2/3 compatibility
+import sys
+PY3 = sys.version_info[0] == 3
+
+if PY3:
+    def b(s):
+        return s
+else:
+    def b(s):
+        return s.encode('utf8')
+
+
 # To minimise memory consumption, we use a namedtuple to store all instance
 # variables, as well as using the __slots__ attribute.
 _URLTuple = namedtuple("_URLTuple", "host username password scheme port path query fragment")
@@ -247,6 +259,10 @@ class URL(object):
             return URL._mutate(self, fragment=value)
         return self._tuple.fragment
 
+    # ====
+    # Path
+    # ====
+
     def path_segment(self, index, value=None, default=None):
         """
         Return the path segment at the given index
@@ -297,6 +313,10 @@ class URL(object):
         segments = self.path_segments() + (value,)
         return self.path_segments(segments)
 
+    # ============
+    # Query params
+    # ============
+
     def has_query_param(self, key):
         """
         Test if a given query parameter is present
@@ -315,7 +335,9 @@ class URL(object):
 
     def query_param(self, key, value=None, default=None, as_list=False):
         """
-        Return a query parameter for the given key
+        Return or set a query parameter for the given key
+
+        The value can be a list.
 
         :param string key: key to look for
         :param string default: value to return if ``key`` isn't found
@@ -334,9 +356,20 @@ class URL(object):
             return result
         return result[0] if len(result) == 1 else result
 
+    def append_query_param(self, key, value):
+        """
+        Append a query parameter
+
+        :param string key: The query param key
+        :param string value: The new value
+        """
+        values = self.query_param(key, as_list=True, default=[])
+        values.append(value)
+        return self.query_param(key, values)
+
     def query_params(self, value=None):
         """
-        Return a dictionary of query params
+        Return or set a dictionary of query params
 
         :param dict value: new dictionary of values
         """
@@ -345,6 +378,23 @@ class URL(object):
         query = '' if self._tuple.query is None else self._tuple.query
         return parse_qs(query, True)
 
+    def remove_query_param(self, key, value=None):
+        """
+        Remove a query param from a URL
+
+        Set the value parameter if removing from a list.
+
+        :param string key: The key to delete
+        :param string value: The value of the param to delete (of more than one)
+        """
+        parse_result = self.query_params()
+        if value is not None:
+            index = parse_result[key].index(value)
+            del parse_result[key][index]
+        else:
+            del parse_result[key]
+        return URL._mutate(self, query=urlencode(parse_result, doseq=True))
+
     @classmethod
     def _mutate(cls, url, **kwargs):
         args = url._tuple._asdict()
